const __ = wp.i18n.__;
const piToDoVars = pi_todo_vars;
document.addEventListener("DOMContentLoaded", function () {
  // Create the constants for document elements
  const piAddItemButton = document.querySelector("#pi_todo_add_item");
  const piToDoListContainer = document.querySelector("#pi-todo-list-container");

  // Array holding all the list items
  let pi_items_object = { pi_todos: [] };

  // Load the content from options table
  if (pi_items_object.pi_todos.length <= 0) {
    if (piToDoVars.todolist != "") {
      pi_items_object = JSON.parse(piToDoVars.todolist);
    }
  }

  // Load the list container with rows
  updateListItemsContainer();
  todosCounter();

  // Add ToDo
  piAddItemButton.addEventListener("click", () => {
    const newInput = document.querySelector("#pi_todo_add_item_text");
    if (newInput.value != "") {
      piCreateRow(pi_items_object.pi_todos.length + 1, false, newInput.value);
      updateListItemsContainer();
      updateListItemsDB();
      newInput.value = "";
    } else {
      alert("Your ToDo can not be empty!");
    }
  });

  // #########  Support functions  #########
  // Create new row in items array
  function piCreateRow(id, isDone, textInput) {
    pi_items_object.pi_todos.push({ isDone: isDone, text: textInput });
  }

  // Create HTML for ToDo row
  function piCreateHTMLRow(index, row, container) {
    // Row container
    const todoRow = document.createElement("div");
    todoRow.setAttribute("class", "pi-items-row");

    // ToDo text
    const rowText = document.createElement("input");
    rowText.setAttribute("class", "pi-item-row-text");
    rowText.setAttribute("type", "text");
    rowText.value = row.text;
    rowText.addEventListener("change", () => {
      pi_items_object.pi_todos[index].text = rowText.value;
      updateListItemsContainer();
      updateListItemsDB();
    });

    // Label for checkbox
    const rowIsDoneLabel = document.createElement("label");
    rowIsDoneLabel.setAttribute("class", "pi-item-is-done-label");
    rowIsDoneLabel.setAttribute("title", __("ToDo done", "pi_todo"));

    // Checkbox input
    const rowIsDone = document.createElement("input");
    rowIsDone.setAttribute("type", "checkbox");
    rowIsDone.setAttribute("class", "pi-item-is-done");

    // Check for checked items in database
    if (pi_items_object.pi_todos[index].isDone == true) {
      rowIsDoneLabel.classList.add("pi-item-is-done-label-checked");
      rowIsDone.classList.add("pi-item-is-done-checked");
      rowText.classList.add("pi-item-row-text-is-done");
    }

    // Event listener for checking ToDo:s
    rowIsDone.addEventListener("click", () => {
      if (rowIsDone.classList.contains("pi-item-is-done-checked")) {
        rowIsDoneLabel.classList.remove("pi-item-is-done-label-checked");
        rowIsDone.classList.remove("pi-item-is-done-checked");
        rowText.classList.remove("pi-item-row-text-is-done");
        pi_items_object.pi_todos[index].isDone = false;
        updateListItemsContainer();
        updateListItemsDB();
      } else {
        rowIsDoneLabel.classList.add("pi-item-is-done-label-checked");
        rowIsDone.classList.add("pi-item-is-done-checked");
        rowText.classList.add("pi-item-row-text-is-done");
        pi_items_object.pi_todos[index].isDone = true;
        updateListItemsContainer();
        updateListItemsDB();
      }
    });
    rowIsDoneLabel.append(rowIsDone);

    // Icon for delete button
    const rowDeleteLabel = document.createElement("label");
    rowDeleteLabel.setAttribute("class", "pi-item-row-delete");
    rowDeleteLabel.setAttribute("title", __("Delete this todo", "pi_todo"));
    rowDeleteLabel.innerHTML = `<?xml version="1.0" encoding="UTF-8"?><svg id="Layer_1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 119.46 133.58"><defs><style>.cls-1{fill:#fff;}</style></defs><path class="cls-1" d="m111.96,10.62h-33.59c.43-.95.68-2,.68-3.12,0-4.14-3.36-7.5-7.5-7.5h-23.64c-4.14,0-7.5,3.36-7.5,7.5,0,1.11.25,2.17.68,3.12H7.5c-4.14,0-7.5,3.36-7.5,7.5s3.36,7.5,7.5,7.5h104.46c4.14,0,7.5-3.36,7.5-7.5s-3.36-7.5-7.5-7.5Z"/><path class="cls-1" d="m27.4,36.38c-.31-4.13-3.9-7.23-8.04-6.92-4.13.31-7.23,3.91-6.92,8.04l6.63,89.14c.29,3.94,3.58,6.94,7.47,6.94.19,0,.38,0,.56-.02,4.13-.31,7.23-3.91,6.92-8.04l-6.63-89.14Z"/><path class="cls-1" d="m100.09,29.45c-4.14-.31-7.73,2.79-8.04,6.92l-6.63,89.14c-.31,4.13,2.79,7.73,6.92,8.04.19.01.38.02.56.02,3.89,0,7.18-3,7.47-6.94l6.63-89.14c.31-4.13-2.79-7.73-6.92-8.04Z"/><path class="cls-1" d="m59.73,29.43c-4.14,0-7.5,3.36-7.5,7.5v89.14c0,4.14,3.36,7.5,7.5,7.5s7.5-3.36,7.5-7.5V36.93c0-4.14-3.36-7.5-7.5-7.5Z"/></svg>`;

    // Delete ToDo button
    const rowDelete = document.createElement("input");
    rowDelete.setAttribute("type", "button");
    rowDelete.setAttribute("class", "pi-item-row-delete-button");
    rowDelete.dataset.itemId = index;

    // Event listener for deleting ToDo:s
    rowDelete.addEventListener("click", (e) => {
      pi_items_object.pi_todos.splice(index, 1);
      updateListItemsContainer();
      updateListItemsDB();
    });

    // Connect the elements and add to container
    rowDeleteLabel.append(rowDelete);
    todoRow.append(rowIsDoneLabel, rowText, rowDeleteLabel);
    container.append(todoRow);
  }

  // Update front-end HTML
  function updateListItemsContainer() {
    piToDoListContainer.innerHTML = "";
    pi_items_object.pi_todos.forEach((item, index) => {
      piCreateHTMLRow(index, item, piToDoListContainer);
    });
  }

  // Update database
  function updateListItemsDB() {
    let formData = new FormData();
    formData.append("action", "pi_update_option");
    formData.append("nonce", piToDoVars.nonce);
    formData.append("listItems", JSON.stringify(pi_items_object));
    fetch(piToDoVars.ajaxurl, {
      method: "POST",
      body: formData,
    })
      .then((res) => res.text())
      .then((data) => console.log(data))
      .catch((err) => console.log(err));
    todosCounter();
  }

  // Count ToDos and display
  function todosCounter() {
    const pi_todos_count = pi_items_object.pi_todos.length;
    let nrDone = 0;
    pi_items_object.pi_todos.forEach((row) => {
      if (row.isDone) nrDone++;
    });

    document.querySelector("#pi_todos_total_counter").innerText = pi_todos_count - nrDone;
    document.querySelector("#pi_todos_done_counter").innerText = nrDone;
  }
});
