<?php
/**
 * Plugin Name: Pivemo ToDo List Dashboard Widget
 * Description: A plugin that adds a simple Todo list widget to the dashboard. Its only visble in the backend.
 * Author: Pivemo
 * Author URI: https://www.pivemo.se
 * Version: 1.0
 * Text Domain: pi_todo
 * Domain Path: /languages
 */

 // Stop unwanted access
 if ( ! defined( 'ABSPATH' ) ) {
	die('Stop, access to this file is restricted.');
}

// Add translation languages
add_action('init', 'pi_add_languages');

function pi_add_languages() {
    load_plugin_textdomain('pi_todo', false, dirname(plugin_basename(__FILE__)) . "/languages");
}

// Check if option exists in WP options tabel
if (!get_option('pi_todo')) {
    update_option('pi_todo', '');
}

// Enqueue scripts and localize variables
add_action( 'admin_enqueue_scripts', 'pi_enqueue_admin_script' );

function pi_enqueue_admin_script() {
    wp_enqueue_script('jquery');
    wp_enqueue_style('pi_todo_widget_custom_style', plugin_dir_url( __FILE__ ) . '/pi_todo_style.css', [], "1.0");
    $screen = get_current_screen(  )->id;

    if ($screen == "dashboard") {
        wp_enqueue_script( 'pi_todo_widget_script', plugin_dir_url( __FILE__ ) . '/pi_todo_app.js', ['wp-i18n'], '1.0' );
    
        wp_localize_script( 'pi_todo_widget_script', 'pi_todo_vars', 
            array(
                'ajaxurl'  => admin_url( 'admin-ajax.php' ),
                'todolist' => stripslashes(get_option('pi_todo')),
                'nonce'    => wp_create_nonce('pi_todo_nonce'),
            ) 
        ); 
    }
}

// Set up Widget 
add_action('wp_dashboard_setup', 'pi_todo_dashboard_widget');

function pi_todo_dashboard_widget() {
    wp_add_dashboard_widget(
        'pi_todo_dashboard_widget',
        'Pivemo ToDo List',
        'pi_todo_list_widget_callback'
    );
}

// Create callback and HTML for Widget
function pi_todo_list_widget_callback() {
    echo pi_todo_list_HTML();
}

function pi_todo_list_HTML() {
?>
<form>
    <div class="input-text-wrap">
        <label for="pi_todo_add_item_text"><?php esc_html_e("Add a ToDo", "pi_todo"); ?></label>
        <input type='text' class='regular-text' id='pi_todo_add_item_text' value="">
    </div>
    <input type='button' name='pi_todo_add_item' class='button button-primary pi-top-margin-10' id='pi_todo_add_item' value="<?php esc_html_e('Save', 'pi_todo'); ?>">
</form>
<div class='pi-todo-list-container' id='pi-todo-list-container'></div>
<div class="pi_todo_count"><?php esc_html_e("Things todo", "pi_todo"); ?>: <span id="pi_todos_total_counter">0</span><span class="pi_todos_count_separator"> | </span><?php esc_html_e("Things done", "pi_todo"); ?>: <span id="pi_todos_done_counter">0</span></div>
<?php
}

// Update options table via ajax
add_action( 'wp_ajax_pi_update_option', 'pi_update_option' );

function pi_update_option() {
    check_ajax_referer('pi_todo_nonce', 'nonce');
    $list_items = $_POST['listItems'];
    update_option('pi_todo', $list_items);
    wp_die();;
}

?>